@@ -22,6 +22,8 @@ __header__ = textwrap.dedent("""
   '/|||\`
   | '|` |
     '|`
+
+Full documentation can be found at: http://ceph.com/ceph-deploy/docs
 """ % ceph_deploy.__version__)
 
 
@@ -62,6 +64,11 @@ def get_parser():
         help='name of the cluster',
         type=validate.alphanumeric,
         )
+    parser.add_argument(
+        '--ceph-conf',
+        dest='ceph_conf',
+        help='use (or reuse) a given ceph.conf file',
+    )
     sub = parser.add_subparsers(
         title='commands',
         metavar='COMMAND',
@@ -84,7 +91,7 @@ def get_parser():
         # the program name, with subcommand, later
         p.set_defaults(prog=p.prog)
         if not os.environ.get('CEPH_DEPLOY_TEST'):
-            p.set_defaults(cd_conf = ceph_deploy.conf.cephdeploy.load())
+            p.set_defaults(cd_conf=ceph_deploy.conf.cephdeploy.load())
 
         fn(p)
     parser.set_defaults(
@@ -92,11 +99,12 @@ def get_parser():
         prog=parser.prog,
         cluster='ceph',
         )
+
     return parser
 
 
-@catches((KeyboardInterrupt, RuntimeError, exc.DeployError,))
-def main(args=None, namespace=None):
+@catches((KeyboardInterrupt, RuntimeError, exc.DeployError,), handle_all=True)
+def _main(args=None, namespace=None):
     parser = get_parser()
 
     if len(sys.argv) < 2:
@@ -131,6 +139,34 @@ def main(args=None, namespace=None):
     root_logger.addHandler(sh)
     root_logger.addHandler(fh)
 
-    LOG.info("Invoked (%s): %s" %(ceph_deploy.__version__,
-                                  join(sys.argv, " ")))
+    # Reads from the config file and sets values for the global
+    # flags and the given sub-command
+    # the one flag that will never work regardless of the config settings is
+    # logging because we cannot set it before hand since the logging config is
+    # not ready yet. This is the earliest we can do.
+    args = ceph_deploy.conf.cephdeploy.set_overrides(args)
+
+    LOG.info("Invoked (%s): %s" % (
+        ceph_deploy.__version__,
+        join(sys.argv, " "))
+    )
+
     return args.func(args)
+
+
+def main(args=None, namespace=None):
+    try:
+        _main(args=args, namespace=namespace)
+    finally:
+        # This block is crucial to avoid having issues with
+        # Python spitting non-sense thread exceptions. We have already
+        # handled what we could, so close stderr and stdout.
+        if not os.environ.get('CEPH_DEPLOY_TEST'):
+            try:
+                sys.stdout.close()
+            except:
+                pass
+            try:
+                sys.stderr.close()
+            except:
+                pass
